<?php
/**
 * Template part for displaying front page about.
 *
 * @package Moral
 */
// Get default  mods value.
$default = magic_blog_pro_get_default_mods();

// Get the content type.
$about = get_theme_mod( 'magic_blog_pro_about', 'custom' );
$trending = get_theme_mod( 'magic_blog_pro_trending', 'custom' );

// Bail if the section is disabled.
if ( 'disable' === $about ) {
	return;
}

if ( 'disable' === $trending ) {
	return;
}
// Query if the content type is either post or page.
if (  in_array( $about, array( 'post', 'page' ) ) ) {

	if ( 'post' === $about ) {
		$id = get_theme_mod( 'magic_blog_pro_about_post' );
	} else {
		$id = get_theme_mod( 'magic_blog_pro_about_page' );
	}

	$query = new WP_Query( array( 'post_type' => $about, 'p' => absint( $id ) ) );

	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			$img_url     = get_the_post_thumbnail_url( $id, 'large' );
			$title   = get_the_title();
			$content = get_the_excerpt();
			$btn_url     = get_permalink();

		}
		wp_reset_postdata();
	}
} else {
	$title   = get_theme_mod( 'magic_blog_pro_about_title', $default['magic_blog_pro_about_title'] );
	$content = get_theme_mod( 'magic_blog_pro_about_content', $default['magic_blog_pro_about_content'] );
	$btn_url     = get_theme_mod( 'magic_blog_pro_about_link' );

	$img_url = get_theme_mod( 'magic_blog_pro_about_image' );
}
// Get the common settings value  in custom, page and post.
$sub_title   = get_theme_mod( 'magic_blog_pro_about_sub_title', $default['magic_blog_pro_about_sub_title'] );
$about_signature_url = get_theme_mod( 'magic_blog_pro_about_signature');


// Query if the trending content type is either post or page.
if (  in_array( $trending, array( 'post', 'page' ) ) ) {

	if ( 'post' === $trending ) {
		$trending_id = get_theme_mod( 'magic_blog_pro_trending_post' );
	} else {
		$trending_id = get_theme_mod( 'magic_blog_pro_trending_page' );
	}

	$the_query = new WP_Query( array( 'post_type' => $trending ) );

	if ( $the_query->have_posts() ) {
		while ( $the_query->have_posts() ) {
			$the_query->the_post();
			$trending_img_url     = get_the_post_thumbnail_url( $trending_id, 'large' );
			$trending_title   = get_the_title();
			$trending_btn_url     = get_permalink();
		}
		wp_reset_postdata();
	}
} else {
	$trending_title   = get_theme_mod( 'magic_blog_pro_trending_title', $default['magic_blog_pro_trending_title'] );
	$trending_btn_url     = get_theme_mod( 'magic_blog_pro_trending_link' );

	$trending_img_url = get_theme_mod( 'magic_blog_pro_trending_image' );
}

$trending_btn_txt = get_theme_mod( 'magic_blog_pro_trending_btn_text', $default['magic_blog_pro_trending_btn_text'] );

?>
<div id="about-us" class="col-2">
    <div class="wrapper">

        <article class="hentry">
            <div class="section-header">
                <p class="section-subtitle"><?php echo esc_html( $sub_title ); ?></p>
                <h2 class="section-title"><?php echo esc_html( $title ); ?></h2>
            </div>

            <div class="about-image">
                <a href="<?php echo esc_url( $btn_url ); ?>"><img src="<?php echo esc_url( $img_url );?>"></a>
            </div>

            <div class="entry-content">
                <p><?php echo wp_kses_post( $content ); ?></p>

                <div class="social-icons">
                    <ul>
	                    <?php 
	                    
        				for ( $i=1; $i <= 5; $i++ ) { 
							$social_link = get_theme_mod( 'magic_blog_pro_about_social_link_' . $i, 'https://facebook.com' );
                            if ( ! empty( $social_link ) ) {
							?>
	        				<li>
	        					<a href="<?php echo esc_url( $social_link ); ?>">
	        						<?php echo magic_blog_pro_get_svg_by_url( $social_link ); ?>
								</a>
							</li>
						<?php } 
                        }
                        
                        ?>
                    </ul>
                </div>
                <img src="<?php echo esc_url( $about_signature_url ); ?>">
            </div><!-- .entry-content -->
        </article><!-- .hentry -->
        <article class=" trending hentry">
            <header class="entry-header">
                <h2 class="entry-title"><?php echo esc_html( $trending_title ); ?></h2>
            </header>

            <div class="featured-image" style="background-image:url('<?php echo esc_url( $trending_img_url ); ?>')">
                <a href="<?php echo esc_html( $trending_btn_url ); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html( $trending_btn_txt ); ?></a>
            </div>
        </article><!-- .hentry -->
    </div><!-- .wrapper -->
</div><!-- #about-us -->

