<?php
/**
 * Template part for displaying front page slider.
 *
 * @package Moral
 */

// Get default  mods value.
$slider = get_theme_mod( 'magic_blog_pro_slider', 'custom' );

if ( 'disable' === $slider ) {
    return;
}

$default = magic_blog_pro_get_default_mods();

$slider_num = get_theme_mod( 'magic_blog_pro_slider_num', 3 );

?>
<div id="featured-slider-section" class="relative">
    <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": true }'>
    	<?php

        	if (  in_array( $slider, array( 'post', 'page', 'cat' ) ) ) {

        	    if ( 'cat' === $slider ) {
        	        $cat_id = get_theme_mod( 'magic_blog_pro_slider_cat' );
        	        $args = array(
        	            'cat' => $cat_id,   
        	            'posts_per_page' => $slider_num,
        	        );
        	    } else {
        	        $id = array();
        	        for ( $i=1; $i <= $slider_num; $i++ ) { 
        	            $id[] = get_theme_mod( "magic_blog_pro_slider_{$slider}_" . $i );
        	        }
        	        $args = array(
        	            'post_type' => $slider,
        	            'post__in' => (array)$id,   
                        'orderby'   => 'post__in',
        	            'posts_per_page' => $slider_num,
        	            'ignore_sticky_posts' => true,
        	        );
        	    }

        	    $query = new WP_Query( $args );

        	    $i = 1;
        	    if ( $query->have_posts() ) :
        	        while ( $query->have_posts() ) :
        	            $query->the_post();
        	            ?>
				        <article style="background-image: url('<?php the_post_thumbnail_url( 'full' ); ?>');">
				            <div class="wrapper">
				                <div class="entry-container" style="">
				                    <div class="entry-meta">
				                        <span class="posted-on">
				                            <span class="screen-reader-text"><?php esc_html_e('Posted on', 'magic-blog-pro'); ?></span> 
				                            <a href="<?php the_permalink(); ?>" rel="bookmark">
				                                <time class="entry-date published" datetime="2018-10-22T06:27:14+00:00"><?php magic_blog_pro_posted_on(); ?></time>
				                                <time class="updated" datetime="2018-10-29T05:26:59+00:00"><?php magic_blog_pro_posted_on(); ?></time>
				                            </a>
				                        </span><!-- .posted-on -->
				                        <span class="byline"><?php esc_html_e('By:', 'magic-blog-pro'); ?> <span class="author vcard">
				                            <a class="url fn n" href=" <?php esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?> "> <?php echo esc_html( get_the_author() ); ?> </a></span>
				                        </span><!-- .byline -->
				                    </div><!-- .entry-meta -->

				                    <header class="entry-header">
				                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
				                    </header>

				                    <div class="entry-content">
				                        <?php the_excerpt(); ?>
				                    </div><!-- .entry-content -->
				                    <div class="read-more">
				                        <a href="<?php the_permalink(); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html( get_theme_mod( 'magic_blog_pro_slider_custom_btn_' . $i, $default['magic_blog_pro_slider_custom_btn'] ) ); ?>
				                        </a>
				                    </div>                           
				                </div>
				            </div><!-- .wrapper-->
				        </article>
				        <?php 
					        $i++;
					    	endwhile;
					        wp_reset_postdata();
					    endif; 
					} else {
					    for ( $i=1; $i <= $slider_num; $i++ ) { 
					        $img_url = get_theme_mod( 'magic_blog_pro_slider_image_' . $i );
					        $content   = get_theme_mod( 'magic_blog_pro_slider_custom_content_' . $i, $default['magic_blog_pro_slider_custom_content'] );
					        $btn_url = get_theme_mod( 'magic_blog_pro_slider_custom_link_' . $i, '#' );
					        $btn_txt = get_theme_mod( 'magic_blog_pro_slider_custom_btn_' . $i, $default['magic_blog_pro_slider_custom_btn'] );
					        
					        ?>
					        <article style="background-image: url( <?php echo esc_url( $img_url );?> );">
								<div class="overlay"></div>
					            <div class="wrapper">
					                <div class="featured-content-wrapper">
					                    <header class="entry-header animated animatedFadeInUp">
					                        <h2 class="entry-title"><?php echo esc_html( $content );?></h2>
					                    </header>
					                    <?php if ( $btn_txt ) : ?>
						                    <div class="more-link animated animatedFadeInUp">
						                        <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-default"><?php echo esc_html( $btn_txt ); ?></a>
						                    </div><!-- .more-link -->
					                    <?php endif; ?>
					                </div><!-- .featured-content-wrapper -->
					            </div><!-- .wrapper -->
					        </article>
					        <article style="background-image: url('<?php echo esc_url( $img_url ); ?>');">
					            <div class="wrapper">
					                <div class="entry-container" style="">
					                    <header class="entry-header">
					                        <h2 class="entry-title"><a href="#"><?php echo esc_html( $content ); ?></a></h2>
					                    </header>

					                    <div class="entry-content">
					                        <?php the_excerpt(); ?>
					                    </div><!-- .entry-content -->
					                    <?php if ( $btn_txt ) : ?>
					                    <div class="read-more">
					                        <a href="<?php echo esc_url( $btn_url ); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html( $btn_txt ); ?>
					                        </a>
					                    </div> 
					                    <?php endif; ?>                          
					                </div>
					            </div><!-- .wrapper-->
					        </article>
					<?php   
					    }
					}
					?>
    </div><!-- .featured-slider -->
</div><!-- #featured-slider-section -->
