<?php
/**
 * Template part for displaying front page video.
 *
 * @package Moral
 */
// Get default  mods value.
$default = magic_blog_pro_get_default_mods();

// Get the content type.
$video = get_theme_mod( 'magic_blog_pro_video', 'custom' );

// Bail if the section is disabled.
if ( 'disable' === $video ) {
	return;
}
// Query if the content type is either post or page.
if (  in_array( $video, array( 'post', 'page' ) ) ) {

	if ( 'post' === $video ) {
		$id = get_theme_mod( 'magic_blog_pro_video_post' );
	} else {
		$id = get_theme_mod( 'magic_blog_pro_video_page' );
	}

	$query = new WP_Query( array( 'post_type' => $video, 'p' => absint( $id ) ) );

	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			$img_url     = get_the_post_thumbnail_url( $id, 'large' );
			$title   = get_the_title();
			$content = get_the_excerpt();
			$btn_url     = get_permalink();

		}
		wp_reset_postdata();
	}
} else {
	$title   = get_theme_mod( 'magic_blog_pro_video_title', $default['magic_blog_pro_video_title'] );
	$content = get_theme_mod( 'magic_blog_pro_video_content', $default['magic_blog_pro_video_content'] );
	$btn_url     = get_theme_mod( 'magic_blog_pro_video_btn_link' );

	$img_url = get_theme_mod( 'magic_blog_pro_video_image' );
}

?>

<div id="video">
    <div class="wrapper">
        <div class="video-wrapper has-featured-image">
            <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url );?>');">
                <div class="icon-play">
                    <?php $video_link = get_theme_mod( 'magic_blog_pro_video_link', 'https://youtu.be/668nUCeBHyY' ); ?>
                    <a class="popup-video" href="<?php echo esc_url( $video_link ); ?>">
                    <svg class="svg-inline--fa fa-play fa-w-14" aria-hidden="true" data-prefix="fas" data-icon="play" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512" data-fa-i2svg=""><path fill="currentColor" d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg>
                    </a>
                </div><!-- .icon-play -->
            </div><!-- .featured-image -->

            <div class="entry-container">
                <?php if ('custom' != $video ): ?>
                <div class="entry-meta">
                    <span class="posted-on">
                        <span class="screen-reader-text"><?php esc_html__('Posted on', 'magic-blog-pro'); ?></span> 
                        <a href="<?php echo esc_url( $btn_url ); ?>" rel="bookmark" tabindex="-1">
                            <time class="entry-date published" datetime="2018-10-22T06:27:14+00:00"><?php magic_blog_pro_posted_on(); ?></time>
                            <time class="updated" datetime="2018-10-29T05:26:59+00:00"><?php magic_blog_pro_posted_on(); ?></time>
                        </a>
                    </span><!-- .posted-on -->
                    <span class="byline"><?php esc_html__('By:', 'magic-blog-pro'); ?><span class="author vcard">
                        <a class="url fn n" href="<?php esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" tabindex="-1"><?php echo esc_html( get_the_author() ); ?></a></span>
                    </span><!-- .byline -->
                </div><!-- .entry-meta -->
                <?php endif; ?>

                <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $btn_url ); ?>" ><?php echo esc_html( $title ); ?> </a> </h2>
                </header><!-- .entry-header -->
                <div class="entry-content">
                   <p> <?php echo wp_kses_post( $content ); ?></p>
                </div><!-- .entry-content -->
                <?php  if ('post'== $video) : ?>
                    <span class="cat-links">
                         <?php the_category(); ?>
                    </span>
                <?php endif; ?>
                <?php
                $video_btn =  get_theme_mod( 'magic_blog_pro_video_btn_txt', $default['magic_blog_pro_video_btn_txt'] );
                 if( ! empty($video_btn)): ?>
                    <div class="more-link">
                        <a href="<?php echo esc_url( $btn_url ); ?>"><?php echo esc_html($video_btn); ?></a>
                    </div>
                 <?php endif; ?>                      
            </div><!-- .entry-container -->
        </div><!-- .video-wrapper -->
    </div><!-- .wrapper -->
</div><!-- #video -->