<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function magic_blog_pro_get_default_mods() {
	$magic_blog_pro_default_mods = array(
		// About
		'magic_blog_pro_about_title' => esc_html__( 'Meet Julia Hanke', 'magic-blog-pro' ),
		'magic_blog_pro_about_sub_title' => esc_html__( 'About Me', 'magic-blog-pro' ),
		'magic_blog_pro_about_content' => esc_html__( 'Beauty is a characteristic of an animal, idea, object, person or place that provides a perceptual experience of pleasure or satisfaction. Beauty is studied as part of aesthetics, culture. ', 'magic-blog-pro' ),
		'magic_blog_pro_about_btn_txt' => esc_html__( 'Know More', 'magic-blog-pro' ),
		'magic_blog_pro_trending_title' => esc_html__( 'Trending on Fashion', 'magic-blog-pro' ),
		'magic_blog_pro_trending_btn_text' => esc_html__( 'Start Shopping', 'magic-blog-pro' ),

		// Popular section
		'magic_blog_pro_popular_section_title' => esc_html__( 'From the Blog', 'magic-blog-pro' ),
		'magic_blog_pro_popular_section_sub_title' => esc_html__( 'Street fashion is fashion that is considered to have emerged not from studios, but from the grassroots streetwear...', 'magic-blog-pro' ),
		'magic_blog_pro_popular_btn_text' => esc_html__( 'Read More', 'magic-blog-pro' ),

		// Video section
		'magic_blog_pro_video_title' => esc_html__( 'We bring emotion to your product', 'magic-blog-pro' ),
		'magic_blog_pro_video_content' => esc_html__( 'Beauty is a characteristic of an animal, idea, object, person or place that provides a perceptual experience of pleasure or satisfaction. Beauty is studied as part of aesthetics, culture..', 'magic-blog-pro' ),
		'magic_blog_pro_video_btn_txt' => esc_html__( 'Read More', 'magic-blog-pro' ),
		
		// Subscribe
		'magic_blog_pro_subscribe_sub_title' => esc_html__( 'Subscribe Now', 'magic-blog-pro' ),
		'magic_blog_pro_subscribe_title' => esc_html__( 'Sign up to get your FREE weekly newsletter!', 'magic-blog-pro' ),
		'magic_blog_pro_subscribe_text' => esc_html__( 'Join 5000+ members of the Community and get my free 10 Day Guide to Busting Your Stress.', 'magic-blog-pro' ),
		'magic_blog_pro_subscribe_placeholder' => esc_html__( 'Enter your email', 'magic-blog-pro' ),
		'magic_blog_pro_subscribe_btn_text' => esc_html__( 'Subscribe', 'magic-blog-pro' ),
		'magic_blog_pro_subscribe_bg_image' => get_theme_file_uri( '/assets/img/subscribe-bg.jpg' ),

		// Sliders
		'magic_blog_pro_slider_custom_content' => esc_html__( 'We carve design in most  possible beautiful way.', 'magic-blog-pro' ),
		'magic_blog_pro_slider_custom_btn' => esc_html__( 'Know More', 'magic-blog-pro' ),

		// Blog section
		'magic_blog_pro_blog_section_title' => esc_html__( 'Stay Updated. Happening Now.', 'magic-blog-pro' ),
		'magic_blog_pro_blog_section_sub_title' => esc_html__( 'Latest Blog', 'magic-blog-pro' ),

		// Footer copyright
		'magic_blog_pro_copyright_txt' => sprintf( esc_html__( 'Theme: %1$s by %2$s.', 'magic-blog-pro' ), 'Magic Blog Pro', '<a href="' . esc_url( 'http://moralthemes.com/' ) . '">Moral Themes</a>' ),

		// Homepage sortable sections
		'magic_blog_pro_sort_home_sections' => array( 'slider', 'about', 'popular-posts', 'video', 'latest-posts', 'subscribe', 'instagram' ),
	);

	return apply_filters( 'magic_blog_pro_default_mods', $magic_blog_pro_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function magic_blog_pro_customize_register( $wp_customize ) {
	/**
	 * Separator custom control
	 *
	 * @version 1.0.0
	 * @since  1.0.0
	 */
	class Magic_Blog_Pro_Separator_Custom_Control extends WP_Customize_Control {
		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'magic-blog-pro-separator';
		/**
		 * Control method
		 *
		 * @since 1.0.0
		 */
		public function render_content() {
			?>
			<p><hr style="border-color: #222; opacity: 0.2;"></p>
			<?php
		}
	}

	/**
	 * The radio image customize control extends the WP_Customize_Control class.  This class allows
	 * developers to create a list of image radio inputs.
	 *
	 * Note, the `$choices` array is slightly different than normal and should be in the form of
	 * `array(
		 *	$value => array( 'color' => $color_value ),
		 *	$value => array( 'color' => $color_value ),
	 * )`
	 *
	 */

	/**
	 * Radio color customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Magic_Blog_Pro_Customize_Control_Radio_Color extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'radio-color';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			// We need to make sure we have the correct color URL.
			foreach ( $this->choices as $value => $args )
				$this->choices[ $value ]['color'] = esc_attr( $args['color'] );

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

			<# _.each( data.choices, function( args, choice ) { #>
				<label>
					<input type="radio" value="{{ choice }}" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}} <# if ( choice === data.value ) { #> checked="checked" <# } #> />

					<span class="screen-reader-text">{{ args.label }}</span>
					
					<# if ( 'custom' != choice ) { #>
						<span class="color-value" style="background-color: {{ args.color }}"></span>
					<# } else { #>
						<span class="color-value custom-color-value"></span>
					<# } #>
				</label>
			<# } ) #>
		<?php }
	}

	$wp_customize->register_control_type( 'Magic_Blog_Pro_Customize_Control_Radio_Color'       );

	class Magic_Blog_Pro_Customize_Control_Sort_Sections extends WP_Customize_Control {

	  	/**
	   	* Control Type
	   	*/
	  	public $type = 'sortable';
	  
		/**
		* Add custom parameters to pass to the JS via JSON.
		*
		* @access public
		* @return void
		*/
	  	public function to_json() {
		  	parent::to_json();

	    	$choices = $this->choices;
	      	$choices = array_filter( array_merge( array_flip( $this->value() ), $choices ) );
		  	$this->json['choices'] = $choices;
		  	$this->json['link']    = $this->get_link();
		  	$this->json['value']   = $this->value();
		  	$this->json['id']      = $this->id;
	  	}

	  	/**
	   	* Render Settings
	   	*/
	  	public function content_template() { ?>
		  	<# if ( ! data.choices ) {
		  		return;
		  	} #>

		    <# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

		    <# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

		    <ul class="magic-blog-pro-sortable-list">

		      	<# _.each( data.choices, function( args, choice ) { #>

		        <li>
		            <input class="magic-blog-pro-sortable-input sortable-hideme" name="{{choice}}" type="hidden"  value="{{ choice }}" />
		            <span class ="menu-item-handle sortable-span">{{args.name}}</span>
		          <i title="<?php esc_attr_e( 'Drag and Move', 'magic-blog-pro' );?>" class="dashicons dashicons-menu magic-blog-pro-drag-handle"></i>
		          <i title="<?php esc_attr_e( 'Edit', 'magic-blog-pro' );?>" class="dashicons dashicons-edit magic-blog-pro-edit" data-jump="{{args.section_id}}"></i>
		        </li>

		        <# } ) #>

		        <li class="sortable-hideme">
		          <input class="magic-blog-pro-sortable-value" {{{ data.link }}} value="{{data.value}}" />
		        </li>

		    </ul>
	  	<?php
	  	}
	}

	$wp_customize->register_control_type( 'Magic_Blog_Pro_Customize_Control_Sort_Sections' );

	$default = magic_blog_pro_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'magic_blog_pro_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'magic_blog_pro_customize_partial_blogdescription',
		) );
	}

	/**
	 *
	 * 
	 * Header panel
	 *
	 * 
	 */
	// Header panel
	$wp_customize->add_panel(
		'magic_blog_pro_header_panel',
		array(
			'title' => esc_html__( 'Header', 'magic-blog-pro' ),
			'priority' => 100
		)
	);

	$wp_customize->get_section( 'title_tagline' )->panel         = 'magic_blog_pro_header_panel';
	$wp_customize->get_section( 'header_image' )->panel         = 'magic_blog_pro_header_panel';

	// Header text display setting
	$wp_customize->add_setting(	
		'magic_blog_pro_header_text_display',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	); 

	$wp_customize->add_control(
		'magic_blog_pro_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'magic-blog-pro' ),
		)
	);

	// Header section
	$wp_customize->add_section(
		'magic_blog_pro_header_section',
		array(
			'title' => esc_html__( 'Header', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_header_panel',
		)
	);

	// Header menu sticky enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_make_menu_sticky',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => false
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_make_menu_sticky',
		array(
			'section'		=> 'magic_blog_pro_header_section',
			'label'			=> esc_html__( 'Make menu sticky.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Header search form settings
	$wp_customize->add_setting(
		'magic_blog_pro_show_search',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_show_search',
		array(
			'section'		=> 'magic_blog_pro_header_section',
			'label'			=> esc_html__( 'Show search.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 * 
	 * Home sections panel
	 *
	 * 
	 */
	// Home sections panel
	$wp_customize->add_panel(
		'magic_blog_pro_home_panel',
		array(
			'title' => esc_html__( 'Homepage', 'magic-blog-pro' ),
			'priority' => 105
		)
	);

	$wp_customize->get_section( 'static_front_page' )->panel         = 'magic_blog_pro_home_panel';

	// Homepage sort section
	$wp_customize->add_section(
		'magic_blog_pro_homepage_section_sort',
		array(
			'title' => esc_html__( 'Sort sections', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Homepage sections sortable.
	$wp_customize->add_setting(	
		'magic_blog_pro_sort_home_sections',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_sort',
			'default'	=> $default['magic_blog_pro_sort_home_sections'],
		)
	);

	$wp_customize->add_control( 
		new Magic_Blog_Pro_Customize_Control_Sort_Sections( 
		$wp_customize,
		'magic_blog_pro_sort_home_sections',
			array(
				'section'		=> 'magic_blog_pro_homepage_section_sort',
				'label'			=> esc_html__( 'Sort sections', 'magic-blog-pro' ),
				'choices'  => array(
		            'slider'    => array(
		            	'name' => esc_html__( 'Slider', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_slider'
		            ), 

		            'about'    => array(
		            	'name' => esc_html__( 'About', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_about'
		            ),

		            'popular-posts'    => array(
		            	'name' => esc_html__( 'Popular Posts', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_popular_section'
		            ), 

		            'video'    => array(
		            	'name' => esc_html__( 'Video', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_video'
		            ),
		          
		            'latest-posts'    => array(
		            	'name' => esc_html__( 'Blog Section', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_blog_section'
		            ), 

		            'subscribe'    => array(
		            	'name' => esc_html__( 'Subscribe', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_enable_subscribe'
		            ),

		            'instagram'    => array(
		            	'name' => esc_html__( 'Instagram', 'magic-blog-pro' ),
		            	'section_id' => 'magic_blog_pro_instagram_enable'
		            ),
		        ),
			)
		)
	);

	// Your latest posts title setting
	$wp_customize->add_setting(	
		'magic_blog_pro_your_latest_posts_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Blogs', 'magic-blog-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_your_latest_posts_title',
		array(
			'section'		=> 'static_front_page',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_latest_posts'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_your_latest_posts_title', 
		array(
	        'selector'            => '.home.blog #page-header .page-title',
			'render_callback'     => 'magic_blog_pro_your_latest_posts_partial_title',
    	) 
    );

	/**
	 * Slider section
	 */
	// Slider section
	$wp_customize->add_section(
		'magic_blog_pro_slider',
		array(
			'title' => esc_html__( 'Slider', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Slider enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_slider',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_slider',
		array(
			'section'		=> 'magic_blog_pro_slider',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
					'page' => esc_html__( 'Page', 'magic-blog-pro' ),
					'cat' => esc_html__( 'Category', 'magic-blog-pro' ),
					'custom' => esc_html__( 'Custom', 'magic-blog-pro' ),
			 	)
		)
	);

	// Slider number setting
	$wp_customize->add_setting(
		'magic_blog_pro_slider_num',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_number_range',
			'default' => 3,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_slider_num',
		array(
			'section'		=> 'magic_blog_pro_slider',
			'label'			=> esc_html__( 'Number of slider:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 9', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_slider_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 9 ),
		)
	);

	// Slider number separator setting
	$wp_customize->add_setting(
		'magic_blog_pro_slider_num_separator',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_html',
		)
	);

	$wp_customize->add_control(
		new Magic_Blog_Pro_Separator_Custom_Control( 
		$wp_customize,
		'magic_blog_pro_slider_num_separator',
			array(
				'section'		=> 'magic_blog_pro_slider',
				'active_callback' => 'magic_blog_pro_if_slider_not_disabled',
				'type'			=> 'magic-blog-pro-separator',
			)
		)
	);

	// Slider category setting
	$wp_customize->add_setting(
		'magic_blog_pro_slider_cat',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_slider_cat',
		array(
			'section'		=> 'magic_blog_pro_slider',
			'label'			=> esc_html__( 'Category:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_slider_cat',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_cat_choices(),
		)
	);

	$slider_num = get_theme_mod( 'magic_blog_pro_slider_num', 3 );
	for ( $i=1; $i <= $slider_num; $i++ ) { 
		// Slider custom image setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_image_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_image',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'magic_blog_pro_slider_image_' . $i,
				array(
					'section'		=> 'magic_blog_pro_slider',
					'label'			=> esc_html__( 'Image ', 'magic-blog-pro' ) . $i,
					'active_callback' => 'magic_blog_pro_if_slider_custom',
				)
			)
		);

	    // Slider custom content setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_custom_content_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_html',
				'default' => $default['magic_blog_pro_slider_custom_content'],
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_slider_custom_content_' . $i,
			array(
				'section'		=> 'magic_blog_pro_slider',
				'label'			=> esc_html__( 'Content ', 'magic-blog-pro' ) . $i,
				'description'			=> esc_html__( 'HTML Allowed', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_slider_custom',
				'type'			=> 'textarea'
			)
		);

		// Slider custom name setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_custom_btn_' . $i,
			array(
				'sanitize_callback' => 'sanitize_text_field',
				'default' => $default['magic_blog_pro_slider_custom_btn'],
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_slider_custom_btn_' . $i,
			array(
				'section'		=> 'magic_blog_pro_slider',
				'label'			=> esc_html__( 'Button text ', 'magic-blog-pro' ) . $i,
				'active_callback' => 'magic_blog_pro_if_slider_not_disabled'
			)
		);

		// Slider custom link setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_custom_link_' . $i,
			array(
				'sanitize_callback' => 'esc_url_raw',
				'default' => '#',
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_slider_custom_link_' . $i,
			array(
				'section'		=> 'magic_blog_pro_slider',
				'label'			=> esc_html__( 'Button link ', 'magic-blog-pro' ) . $i,
				'active_callback' => 'magic_blog_pro_if_slider_custom',
				'type'			=> 'url'
			)
		);


		// Slider post setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_post_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_slider_post_' . $i,
			array(
				'section'		=> 'magic_blog_pro_slider',
				'label'			=> esc_html__( 'Post ', 'magic-blog-pro' ) . $i,
				'active_callback' => 'magic_blog_pro_if_slider_post',
				'type'			=> 'select',
				'choices'		=> magic_blog_pro_get_post_choices(),
			)
		);
		
		// Slider page setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_page_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
				'default' => 0,
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_slider_page_' . $i,
			array(
				'section'		=> 'magic_blog_pro_slider',
				'label'			=> esc_html__( 'Page ', 'magic-blog-pro' ) . $i,
				'type'			=> 'dropdown-pages',
				'active_callback' => 'magic_blog_pro_if_slider_page'
			)
		);
		
		// Slider custom separator setting
		$wp_customize->add_setting(
			'magic_blog_pro_slider_custom_separator_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_html',
			)
		);

		$wp_customize->add_control(
			new Magic_Blog_Pro_Separator_Custom_Control( 
			$wp_customize,
			'magic_blog_pro_slider_custom_separator_' . $i,
				array(
					'section'		=> 'magic_blog_pro_slider',
					'active_callback' => 'magic_blog_pro_if_slider_not_disabled',
					'type'			=> 'magic-blog-pro-separator',
				)
			)
		);
	}

	/**
	 * About section
	 */
	// About section
	$wp_customize->add_section(
		'magic_blog_pro_about',
		array(
			'title' => esc_html__( 'About', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// About enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_about',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
					'page' => esc_html__( 'Page', 'magic-blog-pro' ),
					'custom' => esc_html__( 'Custom', 'magic-blog-pro' ),
			 	)
		)
	);

	// About post setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_post',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_post',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Post:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_about_post',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_choices(),
		)
	);

	// About page setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_page',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_page',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Page:', 'magic-blog-pro' ),
			'type'			=> 'dropdown-pages',
			'active_callback' => 'magic_blog_pro_if_about_page'
		)
	);

	// About image setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_image',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'magic_blog_pro_about_image',
			array(
				'section'		=> 'magic_blog_pro_about',
				'label'			=> esc_html__( 'Image:', 'magic-blog-pro' ),
				'description'			=> esc_html__( 'Recommended Image size 330 X 230 ', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_about_custom',
			)
		)
	);

	// About title setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_about_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_title',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_about_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_about_title', 
		array(
	        'selector'            => '#about-us .section-title',
			'render_callback'     => 'magic_blog_pro_about_partial_title',
    	) 
    );

	// About sub title setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_about_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_sub_title',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Sub title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_about_enabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_about_sub_title', 
		array(
	        'selector'            => '#about-us .section-subtitle',
			'render_callback'     => 'magic_blog_pro_about_partial_sub_title',
    	) 
    );

	// About content setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_content',
		array(
			'sanitize_callback' => 'sanitize_textarea_field',
			'default' => $default['magic_blog_pro_about_content'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_content',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Content:', 'magic-blog-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'magic_blog_pro_if_about_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_about_content', 
		array(
	        'selector'            => '#about-us .entry-content',
			'render_callback'     => 'magic_blog_pro_about_partial_content',
    	) 
    );

    for ( $i=1; $i <=5; $i++ ) { 
			// about custom social link setting
			$wp_customize->add_setting(
				'magic_blog_pro_about_social_link_' . $i,
				array(
					'sanitize_callback' => 'esc_url_raw',
					'default'		=> 'https://facebook.com',
				)
			);

			$wp_customize->add_control(
				'magic_blog_pro_about_social_link_' . $i,
				array(
					'section'		=> 'magic_blog_pro_about',
					'label'			=> esc_html__( 'Social Link ', 'magic-blog-pro' ) . $i,
					'active_callback' => 'magic_blog_pro_if_about_enabled',
					'type'			=> 'url',
				)
			);
		}

	// About link setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_link',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_about_link',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Button Link:', 'magic-blog-pro' ),
			'type'			=> 'url',
			'active_callback' => 'magic_blog_pro_if_about_custom'
		)
	);

	// About image setting
	$wp_customize->add_setting(
		'magic_blog_pro_about_signature',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'magic_blog_pro_about_signature',
			array(
				'section'		=> 'magic_blog_pro_about',
				'label'			=> esc_html__( 'Signature Image:', 'magic-blog-pro' ),
				'description'			=> esc_html__( 'Recommended Image size 415 X 90 ', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_about_enabled',
			)
		)
	);

	// Trending enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_trending',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_trending',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Trending Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
					'page' => esc_html__( 'Page', 'magic-blog-pro' ),
					'custom' => esc_html__( 'Custom', 'magic-blog-pro' ),
			 	)
		)
	);

	// Trending post setting
	$wp_customize->add_setting(
		'magic_blog_pro_trending_post',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_trending_post',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Post:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_trending_post',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_choices(),
		)
	);

	// Trending page setting
	$wp_customize->add_setting(
		'magic_blog_pro_trending_page',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_trending_page',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Page:', 'magic-blog-pro' ),
			'type'			=> 'dropdown-pages',
			'active_callback' => 'magic_blog_pro_if_trending_page'
		)
	);

	// Trending image setting
	$wp_customize->add_setting(
		'magic_blog_pro_trending_image',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'magic_blog_pro_trending_image',
			array(
				'section'		=> 'magic_blog_pro_about',
				'label'			=> esc_html__( 'Trending Image:', 'magic-blog-pro' ),
				'description'			=> esc_html__( 'Recommended Image size 330 X 230 ', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_trending_custom',
			)
		)
	);

	// Trending title setting
	$wp_customize->add_setting(
		'magic_blog_pro_trending_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_trending_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_trending_title',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Trending Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_trending_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_trending_title', 
		array(
	        'selector'            => '#about-us .trending .entry-title',
			'render_callback'     => 'magic_blog_pro_trending_partial_title',
    	) 
    );

    // Trending title setting
	$wp_customize->add_setting(
		'magic_blog_pro_trending_btn_text',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_trending_btn_text'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_trending_btn_text',
		array(
			'section'		=> 'magic_blog_pro_about',
			'label'			=> esc_html__( 'Trending button Text:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_trending_enabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_trending_btn_text', 
		array(
	        'selector'            => '#about-us .trending .btn',
			'render_callback'     => 'magic_blog_pro_trending_partial_btn_text',
    	) 
    );

    /**
	 * Popular Posts section section
	 */
	// Popular Posts section section
	$wp_customize->add_section(
		'magic_blog_pro_popular_section',
		array(
			'title' => esc_html__( 'Popular Posts', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Blog section enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_popular_section',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'recent-posts'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_section',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'recent-posts' => esc_html__( 'Recent Posts', 'magic-blog-pro' ),
					'cat' => esc_html__( 'Category', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
			 	)
		)
	);


	// Blog section title setting
	$wp_customize->add_setting(
		'magic_blog_pro_popular_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_popular_section_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_section_title',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_popular_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_popular_section_title', 
		array(
	        'selector'            => '#popular-post .section-title',
			'render_callback'     => 'magic_blog_pro_popular_section_partial_title',
    	) 
    );

    // Blog section sub title setting
	$wp_customize->add_setting(
		'magic_blog_pro_popular_section_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_popular_section_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_section_sub_title',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Sub Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_popular_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_popular_section_sub_title', 
		array(
	        'selector'            => '#popular-posts .section-header p',
			'render_callback'     => 'magic_blog_pro_popular_section_partial_sub_title',
    	) 
    );

    // Blog section number setting
	$wp_customize->add_setting(
		'magic_blog_pro_popular_section_num',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_number_range',
			'default' => 3,
			// 'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_section_num',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Number of posts:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 6', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_popular_section_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 6 ),
		)
	);

	// Blog section category setting
	$wp_customize->add_setting(
		'magic_blog_pro_popular_section_cat',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_section_cat',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Category:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'The button will be linked to the selected category\'s archive link automatically.', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_popular_section_cat',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_cat_choices(),
		)
	);

	$magic_blog_pro_popular_section_num = get_theme_mod( 'magic_blog_pro_popular_section_num', 3 );
	for ( $i=1; $i <= $magic_blog_pro_popular_section_num; $i++ ) { 
		// Projects post setting
		$wp_customize->add_setting(
			'magic_blog_pro_popular_section_post_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_popular_section_post_' . $i,
			array(
				'section'		=> 'magic_blog_pro_popular_section',
				'label'			=> esc_html__( 'Post ', 'magic-blog-pro' ) . $i,
				'active_callback' => 'magic_blog_pro_if_popular_section_post',
				'type'			=> 'select',
				'choices'		=> magic_blog_pro_get_post_choices(),
			)
		);
	}
	 // Popular title setting
	$wp_customize->add_setting(
		'magic_blog_pro_popular_btn_text',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_popular_btn_text'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_popular_btn_text',
		array(
			'section'		=> 'magic_blog_pro_popular_section',
			'label'			=> esc_html__( 'Popular button Text:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_trending_enabled'
		)
	);


	/**
	 * Video section
	 */
	// Video section
	$wp_customize->add_section(
		'magic_blog_pro_video',
		array(
			'title' => esc_html__( 'Video', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Video enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_video',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'custom'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
					'page' => esc_html__( 'Page', 'magic-blog-pro' ),
					'custom' => esc_html__( 'Custom', 'magic-blog-pro' ),
			 	)
		)
	);

	// Video link setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_link',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => 'https://youtu.be/668nUCeBHyY'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_link',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Video Link:', 'magic-blog-pro' ),
			'type'			=> 'url',
			'active_callback' => 'magic_blog_pro_if_video_enabled'
		)
	);

	// Video post setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_post',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_post',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Post:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_video_post',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_choices(),
		)
	);

	// Video page setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_page',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_page',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Page:', 'magic-blog-pro' ),
			'type'			=> 'dropdown-pages',
			'active_callback' => 'magic_blog_pro_if_video_page'
		)
	);

	// Video image setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_image',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'magic_blog_pro_video_image',
			array(
				'section'		=> 'magic_blog_pro_video',
				'label'			=> esc_html__( 'Image:', 'magic-blog-pro' ),
				'description'			=> esc_html__( 'Recommended Image size 330 X 230 ', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_video_custom',
			)
		)
	);

	// Video title setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_video_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_title',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_video_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_video_title', 
		array(
	        'selector'            => '#video .entry-title',
			'render_callback'     => 'magic_blog_pro_video_partial_title',
    	) 
    );



	// Video content setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_content',
		array(
			'sanitize_callback' => 'sanitize_textarea_field',
			'default' => $default['magic_blog_pro_video_content'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_content',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Content:', 'magic-blog-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'magic_blog_pro_if_video_custom'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_video_content', 
		array(
	        'selector'            => '#video .entry-content',
			'render_callback'     => 'magic_blog_pro_video_partial_content',
    	) 
    );

	// Video button text setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_btn_txt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_video_btn_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_btn_txt',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Button Text:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_video_enabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_video_btn_txt', 
		array(
	        'selector'            => '#video .more-link',
			'render_callback'     => 'magic_blog_pro_video_partial_btn_text',
    	) 
    );

	// Video link setting
	$wp_customize->add_setting(
		'magic_blog_pro_video_btn_link',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_video_btn_link',
		array(
			'section'		=> 'magic_blog_pro_video',
			'label'			=> esc_html__( 'Button Link:', 'magic-blog-pro' ),
			'type'			=> 'url',
			'active_callback' => 'magic_blog_pro_if_video_custom'
		)
	);

	/**
	 * Blog section section
	 */
	// Blog section section
	$wp_customize->add_section(
		'magic_blog_pro_blog_section',
		array(
			'title' => esc_html__( 'Blog section', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Blog section enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_blog_section',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'recent-posts'
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_blog_section',
		array(
			'section'		=> 'magic_blog_pro_blog_section',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Choose where you want to render the content from.', 'magic-blog-pro' ),
			'type'			=> 'select',
			'choices'		=> array( 
					'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
					'recent-posts' => esc_html__( 'Recent Posts', 'magic-blog-pro' ),
					'cat' => esc_html__( 'Category', 'magic-blog-pro' ),
					'post' => esc_html__( 'Post', 'magic-blog-pro' ),
			 	)
		)
	);

	// Blog section title setting
	$wp_customize->add_setting(
		'magic_blog_pro_blog_section_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_blog_section_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_blog_section_title',
		array(
			'section'		=> 'magic_blog_pro_blog_section',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_blog_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_blog_section_title', 
		array(
	        'selector'            => '#latest-posts .section-title',
			'render_callback'     => 'magic_blog_pro_blog_section_partial_title',
    	) 
    );

    // Blog section sub title setting
	$wp_customize->add_setting(
		'magic_blog_pro_blog_section_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_blog_section_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_blog_section_sub_title',
		array(
			'section'		=> 'magic_blog_pro_blog_section',
			'label'			=> esc_html__( 'Sub Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_blog_section_not_disabled'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_blog_section_sub_title', 
		array(
	        'selector'            => '#latest-posts .section-subtitle',
			'render_callback'     => 'magic_blog_pro_blog_section_partial_sub_title',
    	) 
    );

    // Blog section number setting
	$wp_customize->add_setting(
		'magic_blog_pro_blog_section_num',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_number_range',
			'default' => 3,
			// 'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_blog_section_num',
		array(
			'section'		=> 'magic_blog_pro_blog_section',
			'label'			=> esc_html__( 'Number of posts:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Min: 1 | Max: 5', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_blog_section_not_disabled',
			'type'			=> 'number',
			'input_attrs'	=> array( 'min' => 1, 'max' => 5 ),
		)
	);

	// Blog section category setting
	$wp_customize->add_setting(
		'magic_blog_pro_blog_section_cat',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_blog_section_cat',
		array(
			'section'		=> 'magic_blog_pro_blog_section',
			'label'			=> esc_html__( 'Category:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'The button will be linked to the selected category\'s archive link automatically.', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_blog_section_cat',
			'type'			=> 'select',
			'choices'		=> magic_blog_pro_get_post_cat_choices(),
		)
	);

	$magic_blog_pro_blog_section_num = get_theme_mod( 'magic_blog_pro_blog_section_num', 3 );
	for ( $i=1; $i <= $magic_blog_pro_blog_section_num; $i++ ) { 
		// Projects post setting
		$wp_customize->add_setting(
			'magic_blog_pro_blog_section_post_' . $i,
			array(
				'sanitize_callback' => 'magic_blog_pro_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'magic_blog_pro_blog_section_post_' . $i,
			array(
				'section'		=> 'magic_blog_pro_blog_section',
				'label'			=> esc_html__( 'Post ', 'magic-blog-pro' ) . $i,
				'active_callback' => 'magic_blog_pro_if_blog_section_post',
				'type'			=> 'select',
				'choices'		=> magic_blog_pro_get_post_choices(),
			)
		);
	}

	/**
	 * Subscription section
	 */
	// Subscription section
	$wp_customize->add_section(
		'magic_blog_pro_subscribe',
		array(
			'title' => esc_html__( 'Subscription', 'magic-blog-pro' ),
			'description' => sprintf( esc_html__( '%1$sJetpack%2$s should be active and site should be connected to WordPress.com for this section to work.', 'magic-blog-pro' ), '<a target="_blank" href="https://wordpress.org/plugins/jetpack">', '</a>' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	// Subscription enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_subscribe',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_subscribe',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Enable subscribe.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Subscribe title setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_subscribe_sub_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_subscribe_sub_title',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Sub Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_subscribe_enable'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_subscribe_sub_title', 
		array(
	        'selector'            => '#subscribe-us .widgettitle',
			'render_callback'     => 'magic_blog_pro_subscribe_partial_sub_title',
		) 
	);

	// Subscribe title setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_subscribe_title'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_subscribe_title',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_subscribe_enable'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_subscribe_title', 
		array(
	        'selector'            => '#subscribe-us .widgettitle',
			'render_callback'     => 'magic_blog_pro_subscribe_partial_title',
		) 
	);

	// Subscribe text setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_text',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_subscribe_text'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_subscribe_text',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Description:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_subscribe_enable',
			'type'			=> 'textarea'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_subscribe_text', 
		array(
	        'selector'            => '#subscribe-us #subscribe-text p',
			'render_callback'     => 'magic_blog_pro_subscribe_partial_text',
		) 
	);

	// Subscribe placeholder setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_placeholder',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_subscribe_placeholder'],
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_subscribe_placeholder',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Placeholder text:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_subscribe_enable'
		)
	);

	// Subscribe button text setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_btn_text',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => $default['magic_blog_pro_subscribe_btn_text'],
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_subscribe_btn_text',
		array(
			'section'		=> 'magic_blog_pro_subscribe',
			'label'			=> esc_html__( 'Button text:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_if_subscribe_enable'
		)
	);

	// Subscribe image setting
	$wp_customize->add_setting(
		'magic_blog_pro_subscribe_bg_image',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_image',
			'default'		=> $default['magic_blog_pro_subscribe_bg_image'],
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'magic_blog_pro_subscribe_bg_image',
			array(
				'section'		=> 'magic_blog_pro_subscribe',
				'label'			=> esc_html__( 'Background image:', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_subscribe_enable',
			)
		)
	);

	/**
	 *Instagram section
	 */
	//Instagram section
	$wp_customize->add_section(
		'magic_blog_pro_instagram',
		array(
			'title' => esc_html__( 'Your Instagram', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_home_panel',
		)
	);

	//Instagram enable settings
	$wp_customize->add_setting(
		'magic_blog_pro_instagram_enable',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_instagram_enable',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Enable:', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Instagram id
	$wp_customize->add_setting(	
		'magic_blog_pro_insta_token',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => '',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_insta_token',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Instagram Access Token:', 'magic-blog-pro' ),
			'description'			=> __( 'Get your Instagram token ID from <a target="_blank" href="https://instagram.pixelunion.net/"> here </a>', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_insta_enable'
		)
	);

	// Instagram title
	$wp_customize->add_setting(	
		'magic_blog_pro_insta_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'From the Instagram', 'magic-blog-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_insta_title',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_insta_enable'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_insta_title', 
		array(
	        'selector'            => '#instagram .section-title',
			'render_callback'     => 'magic_blog_pro_insta_partial_title',
    	) 
    );

    // Instagram subtitle
	$wp_customize->add_setting(	
		'magic_blog_pro_insta_sub_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Street fashion is fashion that is considered to have emerged not from studios, but from the grassroots streetwear...', 'magic-blog-pro' ),
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_insta_sub_title',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Sub Title:', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_insta_enable'
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_insta_sub_title', 
		array(
	        'selector'            => '#instagram .section-header p',
			'render_callback'     => 'magic_blog_pro_insta_partial_sub_title',
    	) 
    );

	// Instagram column
	$wp_customize->add_setting(	
		'magic_blog_pro_insta_count',
		array(
			'sanitize_callback' => 'absint',
			'default' => 6,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_insta_count',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Number of posts:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Range: 2 to 12', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_insta_enable',
			'input_attrs'	=> array( 'min' => 2, 'max' => 12 ),
			'type'			=> 'number'
		)
	);

	// Instagram column
	$wp_customize->add_setting(	
		'magic_blog_pro_insta_col',
		array(
			'sanitize_callback' => 'absint',
			'default' => 6,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_insta_col',
		array(
			'section'		=> 'magic_blog_pro_instagram',
			'label'			=> esc_html__( 'Column:', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'Range: 2 to 6', 'magic-blog-pro' ),
			'active_callback' => 'magic_blog_pro_is_insta_enable',
			'input_attrs'	=> array( 'min' => 2, 'max' => 6 ),
			'type'			=> 'number'
		)
	);

	/**
	 *
	 * General settings panel
	 * 
	 */
	// General settings panel
	$wp_customize->add_panel(
		'magic_blog_pro_general_panel',
		array(
			'title' => esc_html__( 'Advanced Settings', 'magic-blog-pro' ),
			'priority' => 107
		)
	);

	$wp_customize->get_section( 'colors' )->panel         = 'magic_blog_pro_general_panel';
	
	// Header title color setting
	$wp_customize->add_setting(	
		'magic_blog_pro_header_title_color',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_hex_color',
			'default' => '#ff8737',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'magic_blog_pro_header_title_color',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site title Color:', 'magic-blog-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'magic_blog_pro_header_tagline',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_hex_color',
			'default' => '#929292',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'magic_blog_pro_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'magic-blog-pro' ),
			)
		)
	);
	
	// Color scheme setting
	$wp_customize->add_setting(	
		'magic_blog_pro_color_scheme',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default'	=> 'default',
		)
	);

	$wp_customize->add_control( 
		new Magic_Blog_Pro_Customize_Control_Radio_Color( 
		$wp_customize,
		'magic_blog_pro_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio-color',
			'label'			=> esc_html__( 'Color scheme:', 'magic-blog-pro' ),
			'choices'		=> array( 
				'default' => array( 
					'color' => '#ff8737'
				),
				'blue' => array( 
					'color' => '#00b9ff'
				),
				'green' => array( 
					'color' => '#0cc652'
				),
				'red' => array( 
					'color' => '#E1222A'
				),
				'custom' => array( 
					'color' => '#E1222A'
				),
			),
		)
	)
	);

	// Custom color scheme scheme setting
	$wp_customize->add_setting(	
		'magic_blog_pro_custom_color_scheme',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_hex_color',
			'default' => '#ff8737',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'magic_blog_pro_custom_color_scheme',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Custom color:', 'magic-blog-pro' ),
				'active_callback' => 'magic_blog_pro_if_custom_color_scheme',
			)
		)
	);

	$wp_customize->get_section( 'background_image' )->panel         = 'magic_blog_pro_general_panel';
	$wp_customize->get_section( 'custom_css' )->panel         = 'magic_blog_pro_general_panel';

	/**
	 * General settings
	 */
	// General settings
	$wp_customize->add_section(
		'magic_blog_pro_general_section',
		array(
			'title' => esc_html__( 'General', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Breadcrumb enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_breadcrumb_enable',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_breadcrumb_enable',
		array(
			'section'		=> 'magic_blog_pro_general_section',
			'label'			=> esc_html__( 'Enable breadcrumb.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Backtop enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_back_to_top_enable',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_back_to_top_enable',
		array(
			'section'		=> 'magic_blog_pro_general_section',
			'label'			=> esc_html__( 'Enable Scroll up.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Global Layout
	 */
	// Global Layout
	$wp_customize->add_section(
		'magic_blog_pro_global_layout',
		array(
			'title' => esc_html__( 'Global Layout', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Global site layout setting
	$wp_customize->add_setting(
		'magic_blog_pro_site_layout',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'wide',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_site_layout',
		array(
			'section'		=> 'magic_blog_pro_global_layout',
			'label'			=> esc_html__( 'Site layout', 'magic-blog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'boxed' => esc_html__( 'Boxed', 'magic-blog-pro' ), 
				'wide' => esc_html__( 'Wide', 'magic-blog-pro' ), 
				'frame' => esc_html__( 'Frame', 'magic-blog-pro' ), 
			),
		)
	);

	// Global archive layout setting
	$wp_customize->add_setting(
		'magic_blog_pro_archive_sidebar',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_archive_sidebar',
		array(
			'section'		=> 'magic_blog_pro_global_layout',
			'label'			=> esc_html__( 'Archive Sidebar', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'This option works on all archive pages like: 404, search, date, category, "Your latest posts" and so on.', 'magic-blog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'magic-blog-pro' ), 
				'right' => esc_html__( 'Right', 'magic-blog-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'magic-blog-pro' ), 
			),
		)
	);

	// Global page layout setting
	$wp_customize->add_setting(
		'magic_blog_pro_global_page_layout',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_global_page_layout',
		array(
			'section'		=> 'magic_blog_pro_global_layout',
			'label'			=> esc_html__( 'Global page sidebar', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'This option works only on single pages including "Posts page". This setting can be overridden for single page from the metabox too.', 'magic-blog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'magic-blog-pro' ), 
				'right' => esc_html__( 'Right', 'magic-blog-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'magic-blog-pro' ), 
			),
		)
	);

	// Global post layout setting
	$wp_customize->add_setting(
		'magic_blog_pro_global_post_layout',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'right',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_global_post_layout',
		array(
			'section'		=> 'magic_blog_pro_global_layout',
			'label'			=> esc_html__( 'Global post sidebar', 'magic-blog-pro' ),
			'description'			=> esc_html__( 'This option works only on single posts. This setting can be overridden for single post from the metabox too.', 'magic-blog-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left', 'magic-blog-pro' ), 
				'right' => esc_html__( 'Right', 'magic-blog-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'magic-blog-pro' ), 
			),
		)
	);

	/**
	 * Blog/Archive section 
	 */
	// Blog/Archive section 
	$wp_customize->add_section(
		'magic_blog_pro_archive_settings',
		array(
			'title' => esc_html__( 'Archive/Blog', 'magic-blog-pro' ),
			'description' => esc_html__( 'Settings for archive pages including blog page too.', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Archive excerpt setting
	$wp_customize->add_setting(
		'magic_blog_pro_archive_excerpt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'View the post', 'magic-blog-pro' ),
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_archive_excerpt',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Excerpt more text:', 'magic-blog-pro' ),
		)
	);

	// Archive excerpt length setting
	$wp_customize->add_setting(
		'magic_blog_pro_archive_excerpt_length',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_number_range',
			'default' => 60,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_archive_excerpt_length',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Excerpt more length:', 'magic-blog-pro' ),
			'type'			=> 'number',
			'input_attrs'   => array( 'min' => 5 ),
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_archive_cat',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_archive_cat',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Enable category.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_archive_featured_img',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_archive_featured_img',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Content type setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_archive_content_type',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'excerpt',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_archive_content_type',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Content type:', 'magic-blog-pro' ),
			'choices'		=> array(
				'full-content' => esc_html__( 'Full content', 'magic-blog-pro' ), 
				'excerpt' => esc_html__( 'Excerpt', 'magic-blog-pro' ), 
			),
			'type'			=> 'radio',
		)
	);

	// Pagination type setting
	$wp_customize->add_setting(
		'magic_blog_pro_archive_pagination_type',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_select',
			'default' => 'numeric',
		)
	);

	$archive_pagination_description = '';
	$archive_pagination_choices = array( 
				'disable' => esc_html__( '--Disable--', 'magic-blog-pro' ),
				'numeric' => esc_html__( 'Numeric', 'magic-blog-pro' ),
				'older_newer' => esc_html__( 'Older / Newer', 'magic-blog-pro' ),
			);
	if ( ! class_exists( 'JetPack' ) ) {
		$archive_pagination_description = sprintf( esc_html__( 'We recommend to install %1$sJetpack%2$s and enable %3$sInfinite Scroll%4$s feature for automatic loading of posts.', 'magic-blog-pro' ), '<a target="_blank" href="http://wordpress.org/plugins/jetpack">', '</a>', '<b>', '</b>' );
	} else {
		$archive_pagination_choices['infinite_scroll'] = esc_html__( 'Infinite Load', 'magic-blog-pro' );
	}
	$wp_customize->add_control(
		'magic_blog_pro_archive_pagination_type',
		array(
			'section'		=> 'magic_blog_pro_archive_settings',
			'label'			=> esc_html__( 'Pagination type:', 'magic-blog-pro' ),
			'description'			=>  $archive_pagination_description,
			'type'			=> 'select',
			'choices'		=> $archive_pagination_choices,
		)
	);

	/**
	 * Single setting section 
	 */
	// Single setting section 
	$wp_customize->add_section(
		'magic_blog_pro_single_settings',
		array(
			'title' => esc_html__( 'Single Posts', 'magic-blog-pro' ),
			'description' => esc_html__( 'Settings for all single posts.', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_date',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_date',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable date.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_cat',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_cat',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable category.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_tag',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_tag',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable tags.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_comment',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_comment',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable comment.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_author',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_author',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable author.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_pagination',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_pagination',
		array(
			'section'		=> 'magic_blog_pro_single_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Single pages setting section 
	 */
	// Single pages setting section 
	$wp_customize->add_section(
		'magic_blog_pro_single_page_settings',
		array(
			'title' => esc_html__( 'Single Pages', 'magic-blog-pro' ),
			'description' => esc_html__( 'Settings for all single pages.', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Author enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_page_author',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_page_author',
		array(
			'section'		=> 'magic_blog_pro_single_page_settings',
			'label'			=> esc_html__( 'Enable author.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_single_page_pagination',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_single_page_pagination',
		array(
			'section'		=> 'magic_blog_pro_single_page_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Reset all settings
	 */
	// Reset settings section
	$wp_customize->add_section(
		'magic_blog_pro_reset_sections',
		array(
			'title' => esc_html__( 'Reset all', 'magic-blog-pro' ),
			'description' => esc_html__( 'Reset all settings to default.', 'magic-blog-pro' ),
			'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Reset sortable order setting
	$wp_customize->add_setting(
		'magic_blog_pro_reset_settings',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => false,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_reset_settings',
		array(
			'section'		=> 'magic_blog_pro_reset_sections',
			'label'			=> esc_html__( 'Reset all settings?', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 *
	 * Footer copyright
	 *
	 *
	 */
	// Footer copyright
	$wp_customize->add_section(
		'magic_blog_pro_footer_section',
		array(
			'title' => esc_html__( 'Footer', 'magic-blog-pro' ),
			'priority' => 106,
			// 'panel' => 'magic_blog_pro_general_panel',
		)
	);

	// Footer social menu enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_footer_social_menu',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_footer_social_menu',
		array(
			'section'		=> 'magic_blog_pro_footer_section',
			'label'			=> esc_html__( 'Enable social menu.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer text enable setting
	$wp_customize->add_setting(
		'magic_blog_pro_enable_footer_text',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_enable_footer_text',
		array(
			'section'		=> 'magic_blog_pro_footer_section',
			'label'			=> esc_html__( 'Enable footer text.', 'magic-blog-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer copyright setting
	$wp_customize->add_setting(
		'magic_blog_pro_copyright_txt',
		array(
			'sanitize_callback' => 'magic_blog_pro_sanitize_html',
			'default' => $default['magic_blog_pro_copyright_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'magic_blog_pro_copyright_txt',
		array(
			'section'		=> 'magic_blog_pro_footer_section',
			'label'			=> esc_html__( 'Copyright text:', 'magic-blog-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'magic_blog_pro_if_footer_text_enable',
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'magic_blog_pro_copyright_txt', 
		array(
	        'selector'            => '#colophon .site-info .footer-copyright',
			'render_callback'     => 'magic_blog_pro_copyright_partial',
    	) 
    );
}
add_action( 'customize_register', 'magic_blog_pro_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function magic_blog_pro_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function magic_blog_pro_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function magic_blog_pro_customize_preview_js() {
	wp_enqueue_script( 'magic-blog-pro-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'magic_blog_pro_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function magic_blog_pro_customize_control_js() {


	wp_enqueue_style( 'magic-blog-pro-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'magic-blog-pro-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'magic-blog-pro' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'magic-blog-pro' ),
	);

	wp_localize_script( 'magic-blog-pro-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'magic_blog_pro_customize_control_js' );

/**
 *
 * Sanitization callbacks.
 * 
 */

/**
 * Checkbox sanitization callback example.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function magic_blog_pro_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}


/**
 * HEX Color sanitization callback example.
 *
 * - Sanitization: hex_color
 * - Control: text, WP_Customize_Color_Control
 *
 */
function magic_blog_pro_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! is_null( $hex_color ) ? $hex_color : $setting->default );
}

/**
 * Image sanitization callback example.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 */
function magic_blog_pro_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        'svg'          => 'image/svg+xml'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Select sanitization callback example.
 *
 * - Sanitization: select
 * - Control: select, radio
 */
function magic_blog_pro_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Drop-down Pages sanitization callback example.
 *
 * - Sanitization: dropdown-pages
 * - Control: dropdown-pages
 * 
 */
function magic_blog_pro_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 */
function magic_blog_pro_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/**
 * HTML sanitization callback example.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function magic_blog_pro_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/**
 * Sortable section sanitization callback example.
 *
 * - Sanitization: sortable section
 * - Control: sortable
 *
 * @param string $input Value to be sanitized.
 * @return array Sanitized values as array.
 */
function magic_blog_pro_sanitize_sort( $input ) {
	// Ensure $input is an array.
	if ( ! is_array( $input ) ){
		$input = explode( ',', $input );
	}

	$output = array_map( 'sanitize_text_field', $input );

	return $output;
}

/**
 *
 * Active callbacks.
 * 
 */

/**
 * Check if the about is enabled
 */
function magic_blog_pro_if_about_enabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_about' )->value();
}

/**
 * Check if the about is custom
 */
function magic_blog_pro_if_about_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'magic_blog_pro_about' )->value();
}

/**
 * Check if the about is page
 */
function magic_blog_pro_if_about_page( $control ) {
	return 'page' === $control->manager->get_setting( 'magic_blog_pro_about' )->value();
}

/**
 * Check if the about is post
 */
function magic_blog_pro_if_about_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_about' )->value();
}

/**
 * Check if the trending is enabled
 */
function magic_blog_pro_if_trending_enabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_trending' ) ->value();
}

/**
 * Check if the trending is custom
 */
function magic_blog_pro_if_trending_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'magic_blog_pro_trending' )->value();
}

/**
 * Check if the trending is page
 */
function magic_blog_pro_if_trending_page( $control ) {
	return 'page' === $control->manager->get_setting( 'magic_blog_pro_trending' )->value();
}

/**
 * Check if the trending is post
 */
function magic_blog_pro_if_trending_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_trending' )->value();
}

/**
 * Check if the popular section is not disabled
 */
function magic_blog_pro_if_popular_section_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_popular_section' )->value();
}

/**
 * Check if the popular section is cat
 */
function magic_blog_pro_if_popular_section_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'magic_blog_pro_popular_section' )->value();
}

/**
 * Check if the popular section is post
 */
function magic_blog_pro_if_popular_section_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_popular_section' )->value();
}


/**
 * Check if the video is enabled
 */
function magic_blog_pro_if_video_enabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_video' )->value();
}

/**
 * Check if the video is custom
 */
function magic_blog_pro_if_video_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'magic_blog_pro_video' )->value();
}

/**
 * Check if the video is page
 */
function magic_blog_pro_if_video_page( $control ) {
	return 'page' === $control->manager->get_setting( 'magic_blog_pro_video' )->value();
}

/**
 * Check if the video is post
 */
function magic_blog_pro_if_video_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_video' )->value();
}

/**
 * Check if the slider is not disabled
 */
function magic_blog_pro_if_slider_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_slider' )->value();
}

/**
 * Check if the slider is page
 */
function magic_blog_pro_if_slider_page( $control ) {
	return 'page' === $control->manager->get_setting( 'magic_blog_pro_slider' )->value();
}

/**
 * Check if the slider is post
 */
function magic_blog_pro_if_slider_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_slider' )->value();
}

/**
 * Check if the slider is cat
 */
function magic_blog_pro_if_slider_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'magic_blog_pro_slider' )->value();
}

/**
 * Check if the slider is custom
 */
function magic_blog_pro_if_slider_custom( $control ) {
	return 'custom' === $control->manager->get_setting( 'magic_blog_pro_slider' )->value();
}

/**
 * Check if the subscribe is enabled.
 */
function magic_blog_pro_if_subscribe_enable( $control ) {
	return $control->manager->get_setting( 'magic_blog_pro_enable_subscribe' )->value();
}

/**
 * Check if the blog section is not disabled
 */
function magic_blog_pro_if_blog_section_not_disabled( $control ) {
	return 'disable' != $control->manager->get_setting( 'magic_blog_pro_blog_section' )->value();
}

/**
 * Check if the blog section is cat
 */
function magic_blog_pro_if_blog_section_cat( $control ) {
	return 'cat' === $control->manager->get_setting( 'magic_blog_pro_blog_section' )->value();
}

/**
 * Check if the blog section is post
 */
function magic_blog_pro_if_blog_section_post( $control ) {
	return 'post' === $control->manager->get_setting( 'magic_blog_pro_blog_section' )->value();
}

/**
 * Check if instagram is enabled
 */
function magic_blog_pro_is_insta_enable( $control ) {
	return $control->manager->get_setting( 'magic_blog_pro_instagram_enable' )->value();
}

/**
 * Check if the footer text is enabled
 */
function magic_blog_pro_if_footer_text_enable( $control ) {
	return $control->manager->get_setting( 'magic_blog_pro_enable_footer_text' )->value();
}

/**
 * Check if custom color scheme is enabled
 */
function magic_blog_pro_if_custom_color_scheme( $control ) {
	return 'custom' === $control->manager->get_setting( 'magic_blog_pro_color_scheme' )->value();
}

/**
 * Selective refresh.
 */

/**
 * Selective refresh for about title.
 */
function magic_blog_pro_about_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_about_title' ) );
}

/**
 * Selective refresh for about sub title.
 */
function magic_blog_pro_about_partial_sub_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_about_sub_title' ) );
}

/**
 * Selective refresh for about content.
 */
function magic_blog_pro_about_partial_content() {
	return wp_kses_post( get_theme_mod( 'magic_blog_pro_about_content' ) );
}

/**
 * Selective refresh for about btn text.
 */
function magic_blog_pro_trending_partial_btn_text() {
	return esc_html( get_theme_mod( 'magic_blog_pro_trending_btn_text' ) );
}
/**
 * Selective refresh for about title.
 */
function magic_blog_pro_trending_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_trending_title' ) );
}

/**
 * Selective refresh for about btn text.
 */
function magic_blog_pro_trending_partial_btn_txt() {
	return esc_html( get_theme_mod( 'magic_blog_pro_trending_btn_txt' ) );
}
/**
 * Selective refresh for popular section title.
 */
function magic_blog_pro_popular_section_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_popular_section_title' ) );
}

/**
 * Selective refresh for popular section text.
 */
function magic_blog_pro_popular_section_partial_sub_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_popular_section_sub_title' ) );
}

/**
 * Selective refresh for Popular btn text.
 */
function magic_blog_pro_popular_partial_btn_txt() {
	return esc_html( get_theme_mod( 'magic_blog_pro_popular_btn_txt' ) );
}

/**
 * Selective refresh for video title.
 */
function magic_blog_pro_video_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_video_title' ) );
}

/**
 * Selective refresh for video content.
 */
function magic_blog_pro_video_partial_content() {
	return wp_kses_post( get_theme_mod( 'magic_blog_pro_video_content' ) );
}

/**
 * Selective refresh for video btn text.
 */
function magic_blog_pro_video_partial_btn_text() {
	return esc_html( get_theme_mod( 'magic_blog_pro_video_btn_text' ) );
}

/**
 * Selective refresh for blog section title.
 */
function magic_blog_pro_blog_section_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_blog_section_title' ) );
}

/**
 * Selective refresh for blog section text.
 */
function magic_blog_pro_blog_section_partial_sub_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_blog_section_sub_title' ) );
}

/**
 * Selective refresh for subscribe title.
 */
function magic_blog_pro_subscribe_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_subscribe_title' ) );
}

/**
 * Selective refresh for subscribe text.
 */
function magic_blog_pro_subscribe_partial_text() {
	return esc_html( get_theme_mod( 'magic_blog_pro_subscribe_text' ) );
}

/**
 * Selective refresh for insta title.
 */
function magic_blog_pro_insta_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_insta_title' ) );
}

/**
 * Selective refresh for insta title.
 */
function magic_blog_pro_insta_partial_sub_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_insta_sub_title' ) );
}
/**
 * Selective refresh for footer copyright.
 */
function magic_blog_pro_copyright_partial() {
	return wp_kses_post( get_theme_mod( 'magic_blog_pro_copyright_txt' ) );
}

/**
 * Selective refresh for your latest posts title.
 */
function magic_blog_pro_your_latest_posts_partial_title() {
	return esc_html( get_theme_mod( 'magic_blog_pro_your_latest_posts_title' ) );
}

